#!/usr/bin/perl -w

# VerifyImage by Markus Schmidt <schmidt@boomshop.net> in 2011
# Function to check if a clouds image was downloaded correctly.
# uses Image::Magick
# checks the color of the last 100 pixels. If they're all the same, it is
# declared as corrupt.

# you're looking for a license? Poor idiot .) do whatever you like with these
# randomly scattered chars in a textfile.

use LWP::Simple;
use open IO => ':raw';

my $Filename = "clouds.tmp.jpg";

if(eval "use Image::Magick; 1") {
    require Image::Magick;
    Image::Magick->import();
    print "Verifying image data...\n";
} else {
    print "No PERL-Module Image::Magick found, verification of download not possible.\n";
    exit(1);
}
if(verifyImage($Filename)) {
    # File seems to be okay
    print "Image \"$Filename\" - seems to be downloaded successfully.\n";
    exit(0);
} else {
    # File seems to be corrupt, retrying
    print "Verification of \"$Filename\" failed!\n";
    exit(2);
}

# Returns 0 if the image was not downloaded correctly, 1 in the other case.
# It checks the image via Image::Magick by calling the last 100 pixels of the
# last row checking their color values. If they're all @ 32896 the image is
# supposed to be corrupt.
sub verifyImage
{
    my ($im) = @_;
    my $image=Image::Magick->new;
    $image->Read($im);
    my $r = $g = $b = 0;
    my ($w, $h) = $image->Get('width', 'height');
    for $x (($w-100)..$w) {
        # walk through 100 of the most-right pixels in the last row
        my ($r1, $g1, $b1) = split(/,/, $image->Get('pixel[' . $x . ',' . $h . ']'));
        $r += $r1;
        $g += $g1;
        $b += $b1;
        #print $r1 . ", " . $g1 . ", " . $b1 . "\n";
    }
    if($r + $g + $b < 9967488) {
        # if the summarized color is lower than 9967488 return success
        return(1);
    }
    return(0);
}
